Device management — cudaGetDeviceCount, cudaSetDevice, cudaGetDevice,
cudaGetDeviceProperties, cudaDeviceSynchronize, cudaDeviceReset.
The CUDA Runtime maintains a per-thread current device. This module stores that state in a thread-local and exposes the standard Runtime API surface on top of the underlying driver API.
Structs
- Cuda
Device Prop - Subset of
cudaDevicePropexposed by the Runtime API.
Functions
- device_
reset - Explicitly destroys and cleans up all resources associated with the current device in the current process.
- device_
synchronize - Blocks until all preceding tasks in the current device’s context complete.
- get_
compute_ capability - Returns the compute capability as a
(major, minor)pair. - get_
device - Returns the ordinal of the current CUDA device for the calling thread.
- get_
device_ count - Returns the number of CUDA-capable devices.
- get_
device_ properties - Returns properties of the specified device.
- set_
device - Selects
deviceas the current CUDA device for the calling thread.