Module event

Module event 

CUDA event management.

Implements the CUDA Runtime event API:

  • cudaEventCreate / cudaEventCreateWithFlags
  • cudaEventDestroy
  • cudaEventRecord
  • cudaEventSynchronize
  • cudaEventQuery
  • cudaEventElapsedTime

Structs

CudaEvent
A CUDA event handle.
EventFlags
Flags for event creation.

Functions

event_create
Create a CUDA event with default flags.
event_create_with_flags
Create a CUDA event with the given flags.
event_destroy
Destroy a CUDA event.
event_elapsed_time
Compute the elapsed time between two events in milliseconds.
event_query
Query whether event has been recorded.
event_record
Record event at the current position in stream.
event_record_with_flags
Record event at the current position in stream with flags.
event_synchronize
Block the calling thread until event is recorded.