FuncAttributes

Struct FuncAttributes 

pub struct FuncAttributes {
    pub shared_size_bytes: usize,
    pub const_size_bytes: usize,
    pub local_size_bytes: usize,
    pub max_threads_per_block: u32,
    pub num_regs: u32,
    pub ptx_version: u32,
    pub binary_version: u32,
    pub cache_mode_ca: bool,
    pub max_dynamic_shared_size_bytes: usize,
    pub preferred_shared_memory_carveout: i32,
}
Attributes of a compiled kernel function.

Mirrors cudaFuncAttributes.

Fields

shared_size_bytes: usize

Size in bytes of statically-allocated shared memory per block.

const_size_bytes: usize

Size in bytes of the constant memory used by the function.

local_size_bytes: usize

Size in bytes of local memory used by each thread.

max_threads_per_block: u32

Maximum number of threads per block the function can use.

num_regs: u32

Number of registers used by each thread.

ptx_version: u32

PTX virtual architecture of the function.

binary_version: u32

Binary architecture of the function (same as compute capability × 10).

cache_mode_ca: bool

Cache mode configuration.

max_dynamic_shared_size_bytes: usize

Maximum dynamic shared memory per block.

preferred_shared_memory_carveout: i32

Preferred shared memory carveout.