Module peer

Module peer 

Peer-to-peer device access.

Implements:

  • cudaDeviceCanAccessPeer
  • cudaDeviceEnablePeerAccess
  • cudaDeviceDisablePeerAccess
  • cudaMemcpyPeer / cudaMemcpyPeerAsync

Functions

device_can_access_peer
Check whether device can directly access the memory of peer_device.
device_disable_peer_access
Disable peer access from the current context to peer_device.
device_enable_peer_access
Enable peer access from the current context to the context owning peer_device.
memcpy_peer
Copy count bytes from src on src_device to dst on dst_device.
memcpy_peer_async
Asynchronously copy across devices on stream.