pub fn device_disable_peer_access(peer_device: u32) -> CudaRtResult<()>Expand description
Disable peer access from the current context to peer_device.
Mirrors cudaDeviceDisablePeerAccess.
Errors
Propagates driver errors.
pub fn device_disable_peer_access(peer_device: u32) -> CudaRtResult<()>Disable peer access from the current context to peer_device.
Mirrors cudaDeviceDisablePeerAccess.
Propagates driver errors.