Module profiler

Module profiler 

CUDA profiler control.

Implements:

  • cudaProfilerStart
  • cudaProfilerStop

These allow application code to bracket regions of interest for profiling tools such as Nsight Systems or nvprof.

Structs

ProfilerGuard
RAII guard that calls profiler_start on construction and profiler_stop on drop.

Functions

profiler_start
Start the CUDA profiler.
profiler_stop
Stop the CUDA profiler.