Module stream

Module stream 

CUDA stream management.

Implements the CUDA Runtime stream API:

  • cudaStreamCreate / cudaStreamCreateWithFlags / cudaStreamCreateWithPriority
  • cudaStreamDestroy
  • cudaStreamSynchronize
  • cudaStreamQuery
  • cudaStreamWaitEvent
  • cudaStreamGetPriority
  • cudaStreamGetFlags
  • cudaStreamGetDevice
  • The default stream (cudaStreamDefault / cudaStreamLegacy / cudaStreamPerThread)

Structs

CudaStream
A CUDA stream handle.
StreamFlags
Flags for stream creation.

Functions

stream_create
Create a new CUDA stream with default flags.
stream_create_with_flags
Create a new CUDA stream with the given flags.
stream_create_with_priority
Create a new CUDA stream with the given flags and scheduling priority.
stream_destroy
Destroy a CUDA stream.
stream_get_flags
Returns the flags of stream.
stream_get_priority
Returns the priority of stream.
stream_query
Check whether all preceding operations in stream have completed.
stream_synchronize
Wait until all preceding operations in stream complete.
stream_wait_event
Make all future work submitted to stream wait until event is recorded.