pub fn stream_create_with_priority(
flags: StreamFlags,
priority: i32,
) -> CudaRtResult<CudaStream>Expand description
Create a new CUDA stream with the given flags and scheduling priority.
Mirrors cudaStreamCreateWithPriority.
priority is a signed integer where lower values indicate higher priority.
The valid range can be queried with cudaDeviceGetStreamPriorityRange.
Errors
Propagates driver errors.