pub struct FuncAttributes {
pub shared_size_bytes: usize,
pub const_size_bytes: usize,
pub local_size_bytes: usize,
pub max_threads_per_block: u32,
pub num_regs: u32,
pub ptx_version: u32,
pub binary_version: u32,
pub cache_mode_ca: bool,
pub max_dynamic_shared_size_bytes: usize,
pub preferred_shared_memory_carveout: i32,
}Expand description
Attributes of a compiled kernel function.
Mirrors cudaFuncAttributes.
Fields
Size in bytes of statically-allocated shared memory per block.
const_size_bytes: usizeSize in bytes of the constant memory used by the function.
local_size_bytes: usizeSize in bytes of local memory used by each thread.
max_threads_per_block: u32Maximum number of threads per block the function can use.
num_regs: u32Number of registers used by each thread.
ptx_version: u32PTX virtual architecture of the function.
binary_version: u32Binary architecture of the function (same as compute capability × 10).
cache_mode_ca: boolCache mode configuration.
Maximum dynamic shared memory per block.
Preferred shared memory carveout.